@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.4.0;
+our $VERSION = v0.5.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1373,6 +1373,124 @@ my %CAL = (
         "1230" => "星期六、星期日",
         "1231" => "星期六、星期日",
     },
+
+    2024 => {
+        "0101" => "開國紀念日",
+        "0106" => "星期六、星期日",
+        "0107" => "星期六、星期日",
+        "0113" => "星期六、星期日",
+        "0114" => "星期六、星期日",
+        "0120" => "星期六、星期日",
+        "0121" => "星期六、星期日",
+        "0127" => "星期六、星期日",
+        "0128" => "星期六、星期日",
+        "0203" => "星期六、星期日",
+        "0204" => "星期六、星期日",
+        "0208" => "小年夜",
+        "0209" => "農曆除夕",
+        "0210" => "春節",
+        "0211" => "春節",
+        "0212" => "春節",
+        "0213" => "補假",
+        "0214" => "補假",
+        "0218" => "星期六、星期日",
+        "0224" => "星期六、星期日",
+        "0225" => "星期六、星期日",
+        "0228" => "和平紀念日",
+        "0302" => "星期六、星期日",
+        "0303" => "星期六、星期日",
+        "0309" => "星期六、星期日",
+        "0310" => "星期六、星期日",
+        "0316" => "星期六、星期日",
+        "0317" => "星期六、星期日",
+        "0323" => "星期六、星期日",
+        "0324" => "星期六、星期日",
+        "0330" => "星期六、星期日",
+        "0331" => "星期六、星期日",
+        "0404" => "兒童節及民族掃墓節",
+        "0405" => "補假",
+        "0406" => "星期六、星期日",
+        "0407" => "星期六、星期日",
+        "0413" => "星期六、星期日",
+        "0414" => "星期六、星期日",
+        "0420" => "星期六、星期日",
+        "0421" => "星期六、星期日",
+        "0427" => "星期六、星期日",
+        "0428" => "星期六、星期日",
+        "0504" => "星期六、星期日",
+        "0505" => "星期六、星期日",
+        "0511" => "星期六、星期日",
+        "0512" => "星期六、星期日",
+        "0518" => "星期六、星期日",
+        "0519" => "星期六、星期日",
+        "0525" => "星期六、星期日",
+        "0526" => "星期六、星期日",
+        "0601" => "星期六、星期日",
+        "0602" => "星期六、星期日",
+        "0608" => "星期六、星期日",
+        "0609" => "星期六、星期日",
+        "0610" => "端午節",
+        "0615" => "星期六、星期日",
+        "0616" => "星期六、星期日",
+        "0622" => "星期六、星期日",
+        "0623" => "星期六、星期日",
+        "0629" => "星期六、星期日",
+        "0630" => "星期六、星期日",
+        "0706" => "星期六、星期日",
+        "0707" => "星期六、星期日",
+        "0713" => "星期六、星期日",
+        "0714" => "星期六、星期日",
+        "0720" => "星期六、星期日",
+        "0721" => "星期六、星期日",
+        "0727" => "星期六、星期日",
+        "0728" => "星期六、星期日",
+        "0803" => "星期六、星期日",
+        "0804" => "星期六、星期日",
+        "0810" => "星期六、星期日",
+        "0811" => "星期六、星期日",
+        "0817" => "星期六、星期日",
+        "0818" => "星期六、星期日",
+        "0824" => "星期六、星期日",
+        "0825" => "星期六、星期日",
+        "0831" => "星期六、星期日",
+        "0901" => "星期六、星期日",
+        "0907" => "星期六、星期日",
+        "0908" => "星期六、星期日",
+        "0914" => "星期六、星期日",
+        "0915" => "星期六、星期日",
+        "0917" => "中秋節",
+        "0921" => "星期六、星期日",
+        "0922" => "星期六、星期日",
+        "0928" => "星期六、星期日",
+        "0929" => "星期六、星期日",
+        "1005" => "星期六、星期日",
+        "1006" => "星期六、星期日",
+        "1010" => "國慶日",
+        "1012" => "星期六、星期日",
+        "1013" => "星期六、星期日",
+        "1019" => "星期六、星期日",
+        "1020" => "星期六、星期日",
+        "1026" => "星期六、星期日",
+        "1027" => "星期六、星期日",
+        "1102" => "星期六、星期日",
+        "1103" => "星期六、星期日",
+        "1109" => "星期六、星期日",
+        "1110" => "星期六、星期日",
+        "1116" => "星期六、星期日",
+        "1117" => "星期六、星期日",
+        "1123" => "星期六、星期日",
+        "1124" => "星期六、星期日",
+        "1130" => "星期六、星期日",
+        "1201" => "星期六、星期日",
+        "1207" => "星期六、星期日",
+        "1208" => "星期六、星期日",
+        "1214" => "星期六、星期日",
+        "1215" => "星期六、星期日",
+        "1221" => "星期六、星期日",
+        "1222" => "星期六、星期日",
+        "1228" => "星期六、星期日",
+        "1229" => "星期六、星期日",
+    },
 );
 
 sub new { bless {}, shift };
@@ -1487,11 +1605,12 @@ requires some non-trivial amount of computation to correctly determine
 whether the given date is an holiday or not -- which is not
 implemented at this version.
 
-The current implementation includes all known holidays of year 2019
-and 2020 as a lookup table and should therefore correctly determine
-holidays in those 2 years. It should also determine most of the future
-updates correct by some basic compuation, except for the ones
-generated by the weekend-compensation rule.
+The current implementation includes all known holidays from year 2013
+and 2024 in a lookup table and should therefore correctly determine
+holidays in those years. It should also determine most of the future
+holidays correctly with some basic compuation, except for the ones
+generated by the weekend-compensation rules, which is somewhat
+ambiguous.
 
 Conventionally the holiday calendar for the next year is announcend at
 the end of June and we could start to mix the new information into the
@@ -1542,7 +1661,7 @@ This does the same thing as function C<tw_holidays>.
 
 =head1 SEE ALSO
 
-L<Date::Holidays>, L<https://www.dgpa.gov.tw/informationlist?uid=30>
+L<Date::Holidays>, L<https://www.dgpa.gov.tw/informationlist?uid=30>, L<https://data.gov.tw/dataset/14718>
 
 =head1 AUTHOR
 
